
library(tidyverse)
library(lubridate)
library(scales)
library(openair)
library(gridExtra)
library(grid)
setwd("Q:/ATMOS RESEARCH/Projects/Ceilometer Study/Reports/Report_data/Report_data")


dat <- read_csv("PM10_Merriwa_2020_21.csv")

dat$date <- paste(dat$Date, dat$Time, sep = " ")
dat <- na.omit(dat)

dat$date <- dmy_hms(dat$date)

ggplot(dat, aes(x = date, y = Conc)) +
  geom_line(color = "blue") + 
  scale_x_datetime(breaks = "3 month", minor_breaks = "1 month", date_labels = ("%B %Y")) +
  theme_bw() +
  xlab ("Date") +
  ylab (expression(paste(PM[10]," " ,"(", ug, "/", m^3, ")")))

ggsave(filename = "PM10_timeseries_atmos.png", width = 8, height = 3.5, unit = "in")  



###########
dat_cel <- read_csv("Toan_data_CTM_Cel_apr2021.csv")

dat_cel$datetime <- paste(dat_cel$Date, dat_cel$time, sep = " ")

dat_cel$datetime <- dmy_h(dat_cel$datetime)

dat_cel <- dat_cel %>% gather(pbl, measure, 3:6, -site)

dat_cel$hour <- hour(dat_cel$datetime)
dat_cel$Date <- as.factor(dat_cel$Date)

dat_cel$Date <- factor(dat_cel$Date, levels = c ("20/04/2021", "21/04/2021", "22/04/2021", "23/04/2021", "24/04/2021", "25/04/2021", "26/04/2021", "27/04/2021", "28/04/2021", "29/04/2021", "30/04/2021","1/05/2021", "2/05/2021"))

dat_cel %>% filter(site == "Lidcombe") %>% 
ggplot(., aes(x = as.numeric(hour), y = measure)) +
  #geom_line() +
  geom_point( aes(shape = pbl, color = pbl)) +
  #facet_wrap(.~Date, ncol = 4, scales = "free") +
  facet_wrap(.~Date, ncol = 4, scales = "fixed") +
 theme_bw() +
  ggtitle("Lidcombe") +
  labs (y = "PBL (m)", x = "Hour of the day") +
  theme(legend.position = "bottom", legend.title = element_blank())
ggsave("Lidcombe_atmos2_apr2021.png",  width = 8, height = 4, unit = "in" ) 

dat_cel %>% filter(site == "Merriwa") %>% 
  ggplot(., aes(x = as.numeric(hour), y = measure)) +
  #geom_line() +
  geom_point( aes(shape = pbl, color = pbl)) +
  #facet_wrap(.~Date, ncol = 4, scales = "free") +
  #facet_wrap(.~format(as.Date(Date, '%d/%m/%Y'), '%d %b %Y'), ncol = 4, scales = "fixed") +
  facet_wrap(.~Date, ncol = 4, scales = "fixed") +
  theme_bw() +
  ggtitle("Merriwa") +
  labs (y = "PBL (m)", x = "Hour of the day") +
  theme(legend.position = "bottom", legend.title = element_blank())
ggsave("Merriwa_atmos2_apr2021.png",  width = 8, height = 4, unit = "in" ) 

write.csv (dat_cel, "pbl_ctm_wrf_cl51_2.csv")


#######Stat
dat_stat <- read_csv("CTM_WRF_CL51_statdata_apr30_fix.csv")

dat_stat <- na.omit(dat_stat)
wrf <- modStats(dat_stat, mod = "WRF-CMAQ", obs = "CL51", type = "site")
wrf$cl51_comparision <- "WRF"
ccam <- modStats(dat_stat, mod = "CCAM-CTM", obs = "CL51", type = "site")
ccam$cl51_comparision <- "CCAM"

stat_cl51 <- rbind(wrf, ccam)
#stat_cl51 <- round(stat_cl51[,2:11], digits = 2)

write.csv(stat_cl51, "stat_cl51_stat_apr30_fix.csv", row.names = F)


#### Comparision between all parameters - April 2021 ######

dat_lc <- read_csv("pbl_cl51_wrf_ccam_lid.csv")
colnames(dat_lc)

##CL51 Lidcombe
cl_r2 <- cor(dat_lc$Temperature, dat_lc$CL_BLH, use="complete.obs")
cl_r2 <- round(cl_r2, digits = 2)

p1 <- dat_lc %>% ggplot(aes(CL_BLH, Temperature)) + 
  geom_point(color = "blue", size = 1) +
  #geom_smooth(method = "lm", color = "black", se=F) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
  ylab(expression(paste("Temperature (", degree * C *")"))) +
  geom_text(aes(x = 500, y = 30, label = (paste("r =", cl_r2)))) 

p1

#WRF-CMAQ
wrf_r2 <- cor(dat_lc$Temperature, dat_lc$WRF_BLH, use="complete.obs")
wrf_r2 <- round(wrf_r2, digits = 2)

p2 <- dat_lc %>% ggplot(aes(WRF_BLH, Temperature)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("WRF-CMAQ - PBL (m)") +
  ylab(expression(paste("Temperature (", degree * C *")"))) +
  geom_text(aes(x = 500, y = 30, label = (paste("r =", wrf_r2)))) 
p2

#CCAM-CTM
ccam_r2 <- cor(dat_lc$Temperature, dat_lc$CTM_BLH, use="complete.obs")
ccam_r2 <- round(ccam_r2, digits = 2)

p3 <- dat_lc %>% ggplot(aes(CTM_BLH, Temperature)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CCAM-CTM - PBL (m)") +
  ylab(expression(paste("Temperature (", degree * C *")"))) +
  geom_text(aes(x = 500, y = 30, label = (paste("r =", ccam_r2)))) 
p3

grid.arrange(p1, p2, p3, ncol = 1, top = textGrob("A. Lidcombe",gp=gpar(fontsize=15,font=1)))

g <- arrangeGrob(p1, p2, p3, ncol = 1, top = textGrob("A. Lidcombe",gp=gpar(fontsize=15,font=1)))

ggsave(g, file = "temp_vs_pbl_Lidcombe_atmos2_apr2021.png", width = 4, height = 6, units = "in")

# geom_text(
#   data = med_conc, aes(x = forecast_day, y = median, group = var, label = median),
#   size = 4, color = "blue", position = position_dodge(0.8), vjust = -1.3, hjust = -.5
# )
######################
######################
#####################

#### Comparision between all parameters - April 2021

dat_mw <- read_csv("pbl_cl51_wrf_ccam_mw.csv")
colnames(dat_mw)
dat_mw$Humidity<-as.numeric(dat_mw$Humidity)

##CL51 Merriwa
cl_r2 <- cor(dat_mw$Temperature, dat_mw$CL_BLH, use="complete.obs")
cl_r2 <- round(cl_r2, digits = 2)
cl_r2
p1 <- dat_mw %>% ggplot(aes(CL_BLH, Temperature)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
  ylab(expression(paste("Temperature (", degree * C *")"))) +
  geom_text(aes(x = 500, y = 30, label = (paste("r =", cl_r2)))) 

p1

#WRF-CMAQ
wrf_r2 <- cor(dat_mw$Temperature, dat_mw$WRF_BLH, use="complete.obs")
wrf_r2 <- round(wrf_r2, digits = 2)

p2 <- dat_mw %>% ggplot(aes(WRF_BLH, Temperature)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("WRF-CMAQ - PBL (m)") +
  ylab(expression(paste("Temperature (", degree * C *")"))) +
  geom_text(aes(x = 500, y = 30, label = (paste("r =", wrf_r2)))) 
p2

#CCAM-CTM
ccam_r2 <- cor(dat_mw$Temperature, dat_mw$CTM_BLH, use="complete.obs")
ccam_r2 <- round(ccam_r2, digits = 2)

p3 <- dat_mw %>% ggplot(aes(CTM_BLH, Temperature)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CCAM-CTM - PBL (m)") +
  ylab(expression(paste("Temperature (", degree * C *")"))) +
  geom_text(aes(x = 500, y = 30, label = (paste("r =", ccam_r2)))) 
p3

grid.arrange(p1, p2, p3, ncol = 1, top = textGrob("B. Merriwa",gp=gpar(fontsize=15,font=1)))

h <- arrangeGrob(p1, p2, p3, ncol = 1, top = textGrob("B. Merriwa", gp=gpar(fontsize=15,font=1)))

ggsave(h, file = "temp_vs_pbl_Merriwa_atmos_apr2021.png", width = 4, height = 6, units = "in")


######## Ozone ###############

cl_r2 <- cor(dat_lc$Ozone, dat_lc$CL_BLH, use="complete.obs")
cl_r2 <- round(cl_r2, digits = 2)
cl_r2

cl_r2_mw <- cor(dat_mw$Ozone, dat_mw$CL_BLH, use="complete.obs")
cl_r2_mw <- round(cl_r2_mw, digits = 2)
cl_r2_mw

o1 <- dat_lc %>% ggplot(aes(CL_BLH, Ozone)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
  ylab("Ozone (pphm)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 4, label = (paste("r =", cl_r2)))) 

o1

o1_mw <- dat_mw %>% ggplot(aes(CL_BLH, Ozone)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
  ylab("Ozone (pphm)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 4, label = (paste("r =", cl_r2_mw)))) 

o1_mw


wrf_r2 <- cor(dat_lc$Ozone, dat_lc$WRF_BLH, use="complete.obs")
wrf_r2 <- round(wrf_r2, digits = 2)
wrf_r2

wrf_r2_mw <- cor(dat_mw$Ozone, dat_mw$WRF_BLH, use="complete.obs")
wrf_r2_mw <- round(wrf_r2_mw, digits = 2)
wrf_r2_mw

o2 <- dat_lc %>% ggplot(aes(WRF_BLH, Ozone)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  ylab("Ozone (pphm)") +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 4, label = (paste("r =", wrf_r2)))) 
o2

o2_mw <- dat_mw %>% ggplot(aes(WRF_BLH, Ozone)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  ylab("Ozone (pphm)") +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 4, label = (paste("r =", wrf_r2_mw)))) 
o2_mw

ccam_r2 <- cor(dat_lc$Ozone, dat_lc$CTM_BLH, use="complete.obs")
ccam_r2 <- round(ccam_r2, digits = 2)
ccam_r2

ccam_r2_mw <- cor(dat_mw$Ozone, dat_mw$CTM_BLH, use="complete.obs")
ccam_r2_mw <- round(ccam_r2_mw, digits = 2)
ccam_r2_mw

o3 <- dat_lc %>% ggplot(aes(CTM_BLH, Ozone)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  ylab("Ozone (pphm)") +
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 4, label = (paste("r =", ccam_r2)))) 
o3

o3_mw <- dat_mw %>% ggplot(aes(CTM_BLH, Ozone)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  ylab("Ozone (pphm)") +
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 4, label = (paste("r =", ccam_r2_mw)))) 
o3_mw

grid.arrange(o1, o2, o3, ncol = 1, top = textGrob("PBLH vs. Ozone at Lidcombe",gp=gpar(fontsize=15,font=1)))
h <- arrangeGrob(o1, o2, o3, ncol = 1, top = textGrob("PBLH vs. Ozone at Lidcombe", gp=gpar(fontsize=15,font=1)))

grid.arrange(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob("PBLH vs. Ozone at Merriwa",gp=gpar(fontsize=15,font=1)))
h_mw <- arrangeGrob(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob("PBLH vs. Ozone at Merriwa", gp=gpar(fontsize=15,font=1)))

ggsave(h, file = "ozone_vs_pbl_Lidcombe_atmos2_apr2021.png", width = 4.5, height = 5, units = "in")
ggsave(h_mw, file = "ozone_vs_pbl_Merriwa_atmos2_apr2021.png", width = 4.5, height = 5, units = "in")

######## PM10 ###############

cl_r2 <- cor(dat_lc$PM10, dat_lc$CL_BLH, use="complete.obs")
cl_r2 <- round(cl_r2, digits = 2)
cl_r2

cl_r2_mw <- cor(dat_mw$PM10, dat_mw$CL_BLH, use="complete.obs")
cl_r2_mw <- round(cl_r2_mw, digits = 2)
cl_r2_mw

o1 <- dat_lc %>% ggplot(aes(CL_BLH, PM10)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
#  ylab("PM10 (micrograms/m3)") +
  ylab(expression(paste("PM"["10"], "(",mu,"g/m"^3,")"))) +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 200, label = (paste("r =", cl_r2)))) 

o1

o1_mw <- dat_mw %>% ggplot(aes(CL_BLH, PM10)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
#  ylab("PM10 (micrograms/m3)") +
  ylab(expression(paste("PM"["10"], "(",mu,"g/m"^3,")"))) +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 50, label = (paste("r =", cl_r2_mw)))) 

o1_mw

wrf_r2 <- cor(dat_lc$PM10, dat_lc$WRF_BLH, use="complete.obs")
wrf_r2 <- round(wrf_r2, digits = 2)
wrf_r2

wrf_r2_mw <- cor(dat_mw$PM10, dat_mw$WRF_BLH, use="complete.obs")
wrf_r2_mw <- round(wrf_r2_mw, digits = 2)
wrf_r2_mw

o2 <- dat_lc %>% ggplot(aes(WRF_BLH, PM10)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("PM10 (micrograms/m3)") +
  ylab(expression(paste("PM"["10"], "(",mu,"g/m"^3,")"))) +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 200, label = (paste("r =", wrf_r2)))) 
o2

o2_mw <- dat_mw %>% ggplot(aes(WRF_BLH, PM10)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("PM10 (micrograms/m3)") +
  ylab(expression(paste("PM"["10"], "(",mu,"g/m"^3,")"))) +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 50, label = (paste("r =", wrf_r2_mw)))) 
o2_mw

ccam_r2 <- cor(dat_lc$PM10, dat_lc$CTM_BLH, use="complete.obs")
ccam_r2 <- round(ccam_r2, digits = 2)
ccam_r2

ccam_r2_mw <- cor(dat_mw$PM10, dat_mw$CTM_BLH, use="complete.obs")
ccam_r2_mw <- round(ccam_r2_mw, digits = 2)
ccam_r2_mw

o3 <- dat_lc %>% ggplot(aes(CTM_BLH, PM10)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("PM10 (micrograms/m3)") +
  ylab(expression(paste("PM"["10"], "(",mu,"g/m"^3,")"))) +
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 200, label = (paste("r =", ccam_r2)))) 
o3

o3_mw <- dat_mw %>% ggplot(aes(CTM_BLH, PM10)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("PM10 (micrograms/m3)") +
  ylab(expression(paste("PM"["10"], "(",mu,"g/m"^3,")"))) +
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 50, label = (paste("r =", ccam_r2_mw)))) 
o3_mw

grid.arrange(o1, o2, o3, ncol = 1, top = textGrob(expression(paste("PBLH vs. PM"["10"], " at Lidcombe")),gp=gpar(fontsize=15,font=1)))
h <- arrangeGrob(o1, o2, o3, ncol = 1, top = textGrob(expression(paste("PBLH vs. PM"["10"], " at Lidcombe")), gp=gpar(fontsize=15,font=1)))

grid.arrange(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob(expression(paste("PBLH vs. PM"["10"], " at Merriwa")),gp=gpar(fontsize=15,font=1)))
h_mw <- arrangeGrob(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob(expression(paste("PBLH vs. PM"["10"], " at Merriwa")), gp=gpar(fontsize=15,font=1)))

ggsave(h, file = "PM10_vs_pbl_Lidcombe_atmos2_apr2021.png", width = 4.5, height = 5, units = "in")
ggsave(h_mw, file = "PM10_vs_pbl_Merriwa_atmos2_apr2021.png", width = 4.5, height = 5, units = "in")

######## PM2.5 ###############

cl_r2 <- cor(dat_lc$PM2.5, dat_lc$CL_BLH, use="complete.obs")
cl_r2 <- round(cl_r2, digits = 2)
cl_r2

cl_r2_mw <- cor(dat_mw$PM2.5, dat_mw$CL_BLH, use="complete.obs")
cl_r2_mw <- round(cl_r2_mw, digits = 2)
cl_r2_mw

o1 <- dat_lc %>% ggplot(aes(CL_BLH, PM2.5)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
#  ylab("PM2.5 (micrograms/m3)") +
  ylab(expression(paste("PM"["2.5"], "(",mu,"g/m"^3,")"))) +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 160, label = (paste("r =", cl_r2)))) 

o1

o1_mw <- dat_mw %>% ggplot(aes(CL_BLH, PM2.5)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
#  ylab("PM2.5 (micrograms/m3)") +
  ylab(expression(paste("PM"["2.5"], "(",mu,"g/m"^3,")"))) +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 20, label = (paste("r =", cl_r2_mw)))) 

o1_mw

wrf_r2 <- cor(dat_lc$PM2.5, dat_lc$WRF_BLH, use="complete.obs")
wrf_r2 <- round(wrf_r2, digits = 2)
wrf_r2

wrf_r2_mw <- cor(dat_mw$PM2.5, dat_mw$WRF_BLH, use="complete.obs")
wrf_r2_mw <- round(wrf_r2_mw, digits = 2)
wrf_r2_mw

o2 <- dat_lc %>% ggplot(aes(WRF_BLH, PM2.5)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("PM2.5 (micrograms/m3)") +
  ylab(expression(paste("PM"["2.5"], "(",mu,"g/m"^3,")"))) +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 160, label = (paste("r =", wrf_r2)))) 
o2

o2_mw <- dat_mw %>% ggplot(aes(WRF_BLH, PM2.5)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("PM2.5 (micrograms/m3)") +
  ylab(expression(paste("PM"["2.5"], "(",mu,"g/m"^3,")"))) +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 20, label = (paste("r =", wrf_r2_mw)))) 
o2_mw

ccam_r2 <- cor(dat_lc$PM2.5, dat_lc$CTM_BLH, use="complete.obs")
ccam_r2 <- round(ccam_r2, digits = 2)
ccam_r2

ccam_r2_mw <- cor(dat_mw$PM2.5, dat_mw$CTM_BLH, use="complete.obs")
ccam_r2_mw <- round(ccam_r2_mw, digits = 2)
ccam_r2_mw

o3 <- dat_lc %>% ggplot(aes(CTM_BLH, PM2.5)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("PM2.5 (micrograms/m3)") +
  ylab(expression(paste("PM"["2.5"], "(",mu,"g/m"^3,")"))) +  
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 160, label = (paste("r =", ccam_r2)))) 
o3

o3_mw <- dat_mw %>% ggplot(aes(CTM_BLH, PM2.5)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("PM2.5 (micrograms/m3)") +
#  ylab(expression('PM'[2.5] * ' (micrograms/'*'m'^3*')')) +
  ylab(expression(paste("PM"["2.5"], "(",mu,"g/m"^3,")"))) +
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 20, label = (paste("r = ", ccam_r2_mw)))) 
o3_mw

grid.arrange(o1, o2, o3, ncol = 1, top = textGrob(expression(paste("PBLH vs. PM"["2.5"], " at Lidcombe")),gp=gpar(fontsize=15,font=1)))
h <- arrangeGrob(o1, o2, o3, ncol = 1, top = textGrob(expression(paste("PBLH vs. PM"["2.5"], " at Lidcombe")), gp=gpar(fontsize=15,font=1)))

grid.arrange(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob(expression(paste("PBLH vs. PM"["2.5"], " at Merriwa")),gp=gpar(fontsize=15,font=1)))
h_mw <- arrangeGrob(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob(expression(paste("PBLH vs. PM"["2.5"], " at Merriwa")), gp=gpar(fontsize=15,font=1)))

ggsave(h, file = "PM2.5_vs_pbl_Lidcombe_atmos2_apr2021.png", width = 4.5, height = 5, units = "in")
ggsave(h_mw, file = "PM2.5_vs_pbl_Merriwa_atmos2_apr2021.png", width = 4.5, height = 5, units = "in")

######## NO2 ###############

cl_r2 <- cor(dat_lc$NO2, dat_lc$CL_BLH, use="complete.obs")
cl_r2 <- round(cl_r2, digits = 2)
cl_r2

cl_r2_mw <- cor(dat_mw$NO2, dat_mw$CL_BLH, use="complete.obs")
cl_r2_mw <- round(cl_r2_mw, digits = 2)
cl_r2_mw

o1 <- dat_lc %>% ggplot(aes(CL_BLH, NO2)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
#  ylab("NO2 (pphm)") +
  ylab(expression(paste("NO"["2"], "(pphh)"))) +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 4, label = (paste("r =", cl_r2)))) 

o1

o1_mw <- dat_mw %>% ggplot(aes(CL_BLH, NO2)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
#  ylab("NO2 (pphm)") +
  ylab(expression(paste("NO"["2"], "(pphh)"))) +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 3, label = (paste("r =", cl_r2_mw)))) 

o1_mw

wrf_r2 <- cor(dat_lc$NO2, dat_lc$WRF_BLH, use="complete.obs")
wrf_r2 <- round(wrf_r2, digits = 2)
wrf_r2

wrf_r2_mw <- cor(dat_mw$NO2, dat_mw$WRF_BLH, use="complete.obs")
wrf_r2_mw <- round(wrf_r2_mw, digits = 2)
wrf_r2_mw

o2 <- dat_lc %>% ggplot(aes(WRF_BLH, NO2)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("NO2 (pphm)") +
  ylab(expression(paste("NO"["2"], "(pphh)"))) +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 4, label = (paste("r =", wrf_r2)))) 
o2

o2_mw <- dat_mw %>% ggplot(aes(WRF_BLH, NO2)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("NO2 (pphm)") +
  ylab(expression(paste("NO"["2"], "(pphh)"))) +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 3, label = (paste("r =", wrf_r2_mw)))) 
o2_mw

ccam_r2 <- cor(dat_lc$NO2, dat_lc$CTM_BLH, use="complete.obs")
ccam_r2 <- round(ccam_r2, digits = 2)
ccam_r2

ccam_r2_mw <- cor(dat_mw$NO2, dat_mw$CTM_BLH, use="complete.obs")
ccam_r2_mw <- round(ccam_r2_mw, digits = 2)
ccam_r2_mw

o3 <- dat_lc %>% ggplot(aes(CTM_BLH, NO2)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("NO2 (pphm)") +
  ylab(expression(paste("NO"["2"], "(pphh)"))) +
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 4, label = (paste("r =", ccam_r2)))) 
o3

o3_mw <- dat_mw %>% ggplot(aes(CTM_BLH, NO2)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("NO2 (pphm)") +
  ylab(expression(paste("NO"["2"], "(pphh)"))) +
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 3, label = (paste("r =", ccam_r2_mw)))) 
o3_mw

grid.arrange(o1, o2, o3, ncol = 1, top = textGrob(expression(paste("PBLH vs. NO"["2"], " at Lidcombe")),gp=gpar(fontsize=15,font=1)))
h <- arrangeGrob(o1, o2, o3, ncol = 1, top = textGrob(expression(paste("PBLH vs. NO"["2"], " at Lidcombe")), gp=gpar(fontsize=15,font=1)))

grid.arrange(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob(expression(paste("PBLH vs. NO"["2"], " at Merriwa")),gp=gpar(fontsize=15,font=1)))
h_mw <- arrangeGrob(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob(expression(paste("PBLH vs. NO"["2"], " at Merriwa")), gp=gpar(fontsize=15,font=1)))

ggsave(h, file = "NO2_vs_pbl_Lidcombe_atmos2_apr2021.png", width = 4.5, height = 5, units = "in")
ggsave(h_mw, file = "NO2_vs_pbl_Merriwa_atmos2_apr2021.png", width = 4.5, height = 5, units = "in")

######## NOX ###############

cl_r2 <- cor(dat_lc$NOX, dat_lc$CL_BLH, use="complete.obs")
cl_r2 <- round(cl_r2, digits = 2)
cl_r2

cl_r2_mw <- cor(dat_mw$NOX, dat_mw$CL_BLH, use="complete.obs")
cl_r2_mw <- round(cl_r2_mw, digits = 2)
cl_r2_mw

o1 <- dat_lc %>% ggplot(aes(CL_BLH, NOX)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
#  ylab("NOx (pphm)") +
  ylab(expression(paste("NO"["x"], "(pphh)"))) +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 25, label = (paste("r =", cl_r2)))) 

o1

o1_mw <- dat_mw %>% ggplot(aes(CL_BLH, NOX)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
#  ylab("NOx (pphm)") +
  ylab(expression(paste("NO"["x"], "(pphh)"))) +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 5, label = (paste("r =", cl_r2_mw)))) 

o1_mw

wrf_r2 <- cor(dat_lc$NOX, dat_lc$WRF_BLH, use="complete.obs")
wrf_r2 <- round(wrf_r2, digits = 2)
wrf_r2

wrf_r2_mw <- cor(dat_mw$NOX, dat_mw$WRF_BLH, use="complete.obs")
wrf_r2_mw <- round(wrf_r2_mw, digits = 2)
wrf_r2_mw

o2 <- dat_lc %>% ggplot(aes(WRF_BLH, NOX)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("NOx (pphm)") +
  ylab(expression(paste("NO"["x"], "(pphh)"))) +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 25, label = (paste("r =", wrf_r2)))) 
o2

o2_mw <- dat_mw %>% ggplot(aes(WRF_BLH, NOX)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("NOx (pphm)") +
  ylab(expression(paste("NO"["x"], "(pphh)"))) +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 5, label = (paste("r =", wrf_r2_mw)))) 
o2_mw

ccam_r2 <- cor(dat_lc$NOX, dat_lc$CTM_BLH, use="complete.obs")
ccam_r2 <- round(ccam_r2, digits = 2)
ccam_r2

ccam_r2_mw <- cor(dat_mw$NOX, dat_mw$CTM_BLH, use="complete.obs")
ccam_r2_mw <- round(ccam_r2_mw, digits = 2)
ccam_r2_mw

o3 <- dat_lc %>% ggplot(aes(CTM_BLH, NOX)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("NOx (pphm)") +
  ylab(expression(paste("NO"["x"], "(pphh)"))) +
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 25, label = (paste("r =", ccam_r2)))) 
o3

o3_mw <- dat_mw %>% ggplot(aes(CTM_BLH, NOX)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
#  ylab("NOx (pphm)") +
  ylab(expression(paste("NO"["x"], "(pphh)"))) +
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 500, y = 5, label = (paste("r =", ccam_r2_mw)))) 
o3_mw

grid.arrange(o1, o2, o3, ncol = 1, top = textGrob(expression(paste("PBLH vs. NO"["x"], " at Lidcombe")),gp=gpar(fontsize=15,font=1)))
h <- arrangeGrob(o1, o2, o3, ncol = 1, top = textGrob(expression(paste("PBLH vs. NO"["x"], " at Lidcombe")), gp=gpar(fontsize=15,font=1)))

grid.arrange(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob(expression(paste("PBLH vs. NO"["x"], " at Merriwa")),gp=gpar(fontsize=15,font=1)))
h_mw <- arrangeGrob(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob(expression(paste("PBLH vs. NO"["x"], " at Merriwa")), gp=gpar(fontsize=15,font=1)))

ggsave(h, file = "NOX_vs_pbl_Lidcombe_atmos2_apr2021.png", width = 4.5, height = 5, units = "in")
ggsave(h_mw, file = "NOX_vs_pbl_Merriwa_atmos2_2021.png", width = 4.5, height = 5, units = "in")



#####################
# Humidity
#####################


cl_r2 <- cor(dat_lc$Humidity, dat_lc$CL_BLH, use="complete.obs")
cl_r2 <- round(cl_r2, digits = 2)
cl_r2

cl_r2_mw <- cor(dat_mw$Humidity, dat_mw$CL_BLH, use="complete.obs")
cl_r2_mw <- round(cl_r2_mw, digits = 2)
cl_r2_mw


o1 <- dat_lc %>% ggplot(aes(CL_BLH, Humidity)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
  ylab("RH (%)") +
  xlim(0, 2500) +
  geom_text(aes(x = 2000, y = 80, label = (paste("r =", cl_r2)))) 

o1

o1_mw <- dat_mw %>% ggplot(aes(CL_BLH, Humidity)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  xlab("CL51 - MLH (m)") +
  ylab("RH (%)") +
  xlim(0, 2500) +
  geom_text(aes(x = 2000, y = 80, label = (paste("r =", cl_r2_mw)))) 

o1_mw

wrf_r2 <- cor(dat_lc$Humidity, dat_lc$WRF_BLH, use="complete.obs")
wrf_r2 <- round(wrf_r2, digits = 2)
wrf_r2

wrf_r2_mw <- cor(dat_mw$Humidity, dat_mw$WRF_BLH,use="complete.obs")
wrf_r2_mw <- round(wrf_r2_mw, digits = 2)
wrf_r2_mw


o2 <- dat_lc %>% ggplot(aes(WRF_BLH, Humidity)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  ylab("RH (%)") +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 2000, y = 80, label = (paste("r =", wrf_r2)))) 
o2

o2_mw <- dat_mw %>% ggplot(aes(WRF_BLH, Humidity)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  ylab("RH (%)") +
  xlab("WRF-CMAQ - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 2000, y = 80, label = (paste("r =", wrf_r2_mw)))) 
o2_mw

ccam_r2 <- cor(dat_lc$Humidity, dat_lc$CTM_BLH, use="complete.obs")
ccam_r2 <- round(ccam_r2, digits = 2)
ccam_r2

ccam_r2_mw <- cor(dat_mw$Humidity, dat_mw$CTM_BLH, use="complete.obs")
ccam_r2_mw <- round(ccam_r2_mw, digits = 2)
ccam_r2_mw


o3 <- dat_lc %>% ggplot(aes(CTM_BLH, Humidity)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  ylab("RH (%)") +
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 2000, y = 80, label = (paste("r =", ccam_r2)))) 
o3

o3_mw <- dat_mw %>% ggplot(aes(CTM_BLH, Humidity)) + 
  geom_point(color = "blue", size = 1) +
  geom_smooth(method = "lm", color = "black") +
  theme_bw() + 
  ylab("RH (%)") +
  xlab("CCAM-CTM - PBL (m)") +
  xlim(0, 2500) +
  geom_text(aes(x = 2000, y = 80, label = (paste("r =", ccam_r2_mw)))) 
o3_mw

grid.arrange(o1, o2, o3, ncol = 1, top = textGrob("PBL vs. RH at Lidcombe",gp=gpar(fontsize=15,font=1)))
h <- arrangeGrob(o1, o2, o3, ncol = 1, top = textGrob("PBL vs. RH at Lidcombe", gp=gpar(fontsize=15,font=1)))

grid.arrange(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob("PBL vs. RH at Merriwa",gp=gpar(fontsize=15,font=1)))
h_mw <- arrangeGrob(o1_mw, o2_mw, o3_mw, ncol = 1, top = textGrob("PBL vs. RH at Merriwa", gp=gpar(fontsize=15,font=1)))

ggsave(h, file = "RH_vs_pbl_Lidcombe_atmos2_apr2021.png", width = 4.5, height = 5, units = "in")
ggsave(h_mw, file = "RH_vs_pbl_Merriwa_atmos2_aapr2021.png", width = 4.5, height = 5, units = "in")

